@@ -55,11 +55,16 @@ class RuntimeConfig(lime_admin.plugins.AdminPlugin):
         Raises:
             `lime_admin.plugins.NotFoundError` if the config doesn't exist.
         """
+        defaultConfig = {
+            "scriveHost": "https://lime.scrive.com"
+        }
         try:
-            return super().get_config()
+            config = super().get_config()
+            if not "scriveHost" in config:
+                config["scriveHost"] = defaultConfig["scriveHost"]
+            return config
         except lime_admin.plugins.NotFoundError:
-            print("LEEEEEEEEEEEEEEEEEEEEEEEEEEEEEELLLLLL")
-            return {}
+            return defaultConfig
 
     def get_schema(self):
         """Function to retrieve a schema for the config.
